Package: documentosbr
Type: Package
Title: Validate Brazilian Administrative Registers - Valida Documentos
Version: 0.2.0
Authors@R: c(
    person(
      "Gustavo",
      "Coelho",
      role=c("aut"),
      email="gustavo.coelho@ipea.gov.br"
      ),
    person(
      "Lucas","Mation", 
      role = c("aut"),
      comment = c(ORCID = "0000-0002-7461-932X")
      ),
    person(
      "Rodrigo", "Borges",
      email = "rodrigo.borges@ipea.gov.br",
      role = c("ctb","cre"),
      comment = c(ORCID = "0000-0003-2076-1424")
      ),
    person("Ipea - Institue for Applied Economic Research", role = c("cph", "fnd"))
    )
Maintainer: Rodrigo Borges <rodrigo.borges@ipea.gov.br>
Description: Contains functions to validate administrative register as 
             CPF (Cadastro de Pessoa Fisica), CNPJ (Cadastro de Pessoa Juridica), 
             PIS (Programa de Integracao Social),
             CNES (Cadastro Nacional de Saude). 
             Builds from and improves on previous package from IPEA validaRA <https://github.com/ipea/validaRA>.
             It can check individual registers or help creating a table summarizing validity of a set.
License: GPL-3
Encoding: UTF-8
URL: https://github.com/ipea/documentosbr
BugReports: https://github.com/ipea/documentosbr/issues
Suggests: testthat, knitr, covr, rmarkdown
RoxygenNote: 7.3.2
Depends: R (>= 3.0)
LinkingTo: Rcpp, BH
Imports: Rcpp, bit64, stringr, data.table
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-04-28 13:53:01 UTC; borges
Author: Gustavo Coelho [aut],
  Lucas Mation [aut] (ORCID: <https://orcid.org/0000-0002-7461-932X>),
  Rodrigo Borges [ctb, cre] (ORCID:
    <https://orcid.org/0000-0003-2076-1424>),
  Ipea - Institue for Applied Economic Research [cph, fnd]
Repository: CRAN
Date/Publication: 2026-05-05 11:50:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-05 13:37:55 UTC; unix
Archs: documentosbr.so.dSYM

Package: documentosbr
Type: Package
Title: Validate Brazilian Administrative Registers - Valida Documentos
Version: 0.2.0
Authors@R: c(
    person(
      "Gustavo",
      "Coelho",
      role=c("aut"),
      email="gustavo.coelho@ipea.gov.br"
      ),
    person(
      "Lucas","Mation", 
      role = c("aut"),
      comment = c(ORCID = "0000-0002-7461-932X")
      ),
    person(
      "Rodrigo", "Borges",
      email = "rodrigo.borges@ipea.gov.br",
      role = c("ctb","cre"),
      comment = c(ORCID = "0000-0003-2076-1424")
      ),
    person("Ipea - Institue for Applied Economic Research", role = c("cph", "fnd"))
    )
Maintainer: Rodrigo Borges <rodrigo.borges@ipea.gov.br>
Description: Contains functions to validate administrative register as 
             CPF (Cadastro de Pessoa Fisica), CNPJ (Cadastro de Pessoa Juridica), 
             PIS (Programa de Integracao Social),
             CNES (Cadastro Nacional de Saude). 
             Builds from and improves on previous package from IPEA validaRA <https://github.com/ipea/validaRA>.
             It can check individual registers or help creating a table summarizing validity of a set.
License: GPL-3
Encoding: UTF-8
URL: https://github.com/ipea/documentosbr
BugReports: https://github.com/ipea/documentosbr/issues
Suggests: testthat, knitr, covr, rmarkdown
RoxygenNote: 7.3.2
Depends: R (>= 3.0)
LinkingTo: Rcpp, BH
Imports: Rcpp, bit64, stringr, data.table
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-04-28 13:53:01 UTC; borges
Author: Gustavo Coelho [aut],
  Lucas Mation [aut] (ORCID: <https://orcid.org/0000-0002-7461-932X>),
  Rodrigo Borges [ctb, cre] (ORCID:
    <https://orcid.org/0000-0003-2076-1424>),
  Ipea - Institue for Applied Economic Research [cph, fnd]
Repository: CRAN
Date/Publication: 2026-05-05 11:50:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-05-05 16:16:34 UTC; unix
Archs: documentosbr.so.dSYM

# Generated by roxygen2: do not edit by hand

export(doc2integer64)
export(gera_digito)
export(trata_cpf)
export(valida_doc)
export(valida_doc_df)
export(verificar_titulo_eleitor)
import(bit64)
import(data.table)
import(stringr)
importFrom(Rcpp,sourceCpp)
useDynLib(documentosbr, .registration = TRUE)

<!-- README.md is generated from README.Rmd. Please edit that file -->

# documentosbr

[![check](https://github.com/ipea/documentosbr/actions/workflows/check.yaml/badge.svg)](https://github.com/ipea/documentosbr/actions/workflows/check.yaml)
[![Cran](https://www.r-pkg.org/badges/version/validaRA)](https://www.r-pkg.org/badges/version/validaRA)
[![Downloads](https://cranlogs.r-pkg.org/badges/grand-total/validaRA)](https://cranlogs.r-pkg.org/badges/grand-total/validaRA)
[![Coverage
Status](https://codecov.io/gh/ipea/documentosbr/graph/badge.svg)](https://app.codecov.io/github/IPEA/documentosbr?branch=master)
[![CRAN/METACRAN Total
downloads](https://cranlogs.r-pkg.org/badges/grand-total/validaRA?color=blue)](https://CRAN.R-project.org/package=validaRA)
[![Lifecycle:
experimental](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)

<img align="right" src="man/figures/documentosbr.svg" alt="logo" width="140">
<img align="right" src="man/figures/documentosbrlight.svg" alt="logolight" width="140">

## work in progress

### NEW:

- Fixed out of memory write errors in C++ code

### COMMING SOON:

- Validate ibge cities numbers
- Generate last digits for any RA document

## Description

This package contains functions to work with brazilian documents ids as
CPF, PIS, CNPJ and CNS. It can validate them, outputting the result on
different ways. Also, it can handle situations where the ids has just
its prefix(first ten digits, on cpf, for example) and the user needs to
generate the last one.

## Installation

After CRAN approval, it will be possible to install documentosbr from
[CRAN](https://cran.r-project.org/package=documentosbr):

``` r
install.packages("documentosbr")
```

The development version can be installed with remotes or devtools, as in
the following example:

``` r
install.packages("devtools") 
```

After that, it is possible install documentosbr from the github
repository using devtools:

``` r
devtools::install_github("ipea/documentosbr") 
```

NOTE: The package depends on C++ code that has to be compiled, so Rtools
must be installed. It can be found
[here](https://cran.r-project.org/bin/windows/Rtools/)

## Basic Usage

``` r
# Validanting cpf
result <- valida_doc(c("788.346.838-38"), type = "cpf")

# Validanting pis
result <- valida_doc(c("788.346.838-38"), type = "pis")
```

#' Validar Título de Eleitor
#'
#' @description
#' Verifica se um número de Título de Eleitor é válido utilizando o algoritmo 
#' de dígito verificador baseado em pesos e restos de divisão (módulo 11).
#'
#' @param entrada Um \code{character}, \code{numeric} ou \code{integer} representando 
#' o número do título. Caracteres não numéricos são removidos automaticamente.
#' @param log \code{logical}. Se \code{TRUE}, permite o rastreio do processo (atualmente não implementado no corpo da função).
#'
#' @return Retorna um valor lógico: \code{TRUE} se o título for válido, 
#' \code{FALSE} caso contrário.
#' 
#' @export
#'
#' @examples
#' # Exemplo com título válido (formato string)
#' verificar_titulo_eleitor("293116340175")
#' 
#' # Exemplo com título válido (formato numérico)
#' verificar_titulo_eleitor(293116340175)
#' 
#' # Exemplo com título inválido
#' verificar_titulo_eleitor("123456789012")

verificar_titulo_eleitor <- function(entrada, log = FALSE){
  if(is.integer(entrada) | is.numeric(entrada)){
    entrada <- as.character(entrada)
  }
  entrada<- gsub("[^0-9]", "", entrada)
  entrada <- as.numeric(unlist(strsplit(entrada, "")))
  tamanho_entrada <- length(entrada)
  vetor_de_validacao_sequencial <- c(seq(14 - tamanho_entrada, 9), rep(0,4))
  digito_verificador <- entrada[tamanho_entrada - 1]
  resultado <- sum(entrada * vetor_de_validacao_sequencial) %% 11
  if(resultado == 10) resultado <- 0
  if(resultado == digito_verificador){
    saida <- TRUE
  }else{
    saida <- FALSE
  }
  if(saida == TRUE){
    vetor_de_validacao_sequencial <- c(rep(0,tamanho_entrada-4), 7:9, 0)
    digito_verificador <- entrada[tamanho_entrada]
    resultado <- sum(entrada * vetor_de_validacao_sequencial) %% 11
    if(resultado == 10) resultado <- 0
    if(resultado == digito_verificador){
      saida <- TRUE
    }else{
      saida <- FALSE
    }
  }
  saida
}

#' Correct Brazilian cpf document.
#'
#' \code{trada_cpf} The aim is transform the entrada to the pattern of Brazilian document cpf.
#'                  It must have 11 numeric characters. When a dataset is read as a numeric,
#'                  it lost the 0 character on the left. This function fix that lost and transform
#'                  entrada to character.
#'
#'
#' @param entrada Character or numeric of the document that will be adjusted.
#'
#' @return Entrada adjusted.
#' @import stringr
#'
#' @examples
#'    trata_cpf(52145795)
#' @export
#'
trata_cpf <- function(entrada){
  stringr::str_pad(entrada,11, side = "left", pad = "0")
}

#' Convert Brazilian documents.
#'
#' \code{doc2integer64} returns a Brazilian document without special characters and as an integer64.
#'
#'
#' @param entrada Character or numeric that will be converted.
#' @import bit64
#' @return an bit64 integer
#'
#' @examples
#'    doc2integer64("086.090.705-65")
#' @export
#'
doc2integer64 <- function(entrada){
  requireNamespace("bit64")
  converter_ra_(entrada)
}

estatisticas_amostra <- function(dados, columnName,  type = "cpf"){
  erros <- NULL
  setDT(dados)
  dados_validados <- valida_doc(dados[[columnName]], type = type, log = TRUE)
  setDT(dados_validados)
  log <- dados_validados[, .N, by=erros]
  #t <- data.table("Corretos"=0,"Primeiro digito errado"=1,"Segundo Digito errado"=2,"Todos os digitos iguais"=3)
  #log[, erros:=names(t)[match(erros, t)]]
  return(log)

}


diagnostica_RA <- function(df, nomes_colunas, types){
  if(length(types) != length(nomes_colunas)){
    stop("Types e nomes_colunas devem ter o mesmo tamanho")
  }
  todas <- mapply(function(column, type){
    result <- estatisticas_amostra(df, column, type)
    result[, type:= type]
    return(result)
  }, nomes_colunas, types, SIMPLIFY = F)
  todas <- rbindlist(todas)
  return(todas)
}

#' Complete Brazilian documents.
#'
#' \code{gera_digito} generate the last digit of a administrative register.
#'
#'
#' @param entrada Character or numeric of the document that will be validated.
#' @param type Character, it could be CPF, CNPF, PIS e titulo de eleitor.
#'
#' @useDynLib documentosbr, .registration = TRUE
#' @importFrom Rcpp sourceCpp
#' @return it will alter the number by reference.
#'
#' @examples
#'  gera_digito("529.982.247-2", type = "cpf")
#'  gera_digito("60.149.443/0001-7", type = "cnpj")
#' @export
#'
gera_digito <- function(entrada, type = "cpf"){
  generate_digit(entrada, type)
}

context("Teste do PIS")

test_that("PIS is giving with especial caracters", {
  saida <- valida_doc("12345678919", type = "pis")
  expect_equal(saida, TRUE)
})

test_that("PIS is giving with just caracters", {
  saida <- valida_doc("123.456.789-19", type = "pis")
  expect_equal(saida, TRUE)
})

test_that("PIS is giving as a numeric", {
  saida <- valida_doc(12345678919, type = "pis")
  expect_equal(saida, TRUE)
})

test_that("A wrong PIS is giving", {
  saida <- valida_doc(12345678918, type = "pis")
  expect_equal(saida, FALSE)
})

test_that("PIS is givin a data frame column", {
  pis <- c(45993824692, 16630925956, 16345860949)
  names <- c("BB", "Caixa", "Ipea")
  df <- data.frame(names = names, pis = pis)
  result <- valida_doc(df$pis, type = "pis")
  expect_equal(result, c(TRUE, TRUE, TRUE))
})

test_that("PIS using log", {
  pis <- c(45993824692, 12345678918, 16345860949)
  names <- c("BB", "Caixa", "Ipea")
  df <- data.frame(names = names, pis = pis)
  dfr <- data.table(dado=pis,resultado=c(TRUE,FALSE,TRUE), erros=c("Corretos", "Primeiro digito errado", "Corretos"), stringsAsFactors = FALSE)
  result <- valida_doc(df$pis, type = "pis", log = TRUE)
  expect_equal(result, dfr)
})

test_that("Generate pis", {
  pis_correto <- c("45993824692", "16630925956", "16345860949")
  pis_incorreto <- c("4599382469", "1663092595", "1634586094")
  gera_digito(pis_incorreto, type = "pis")
  expect_equal(pis_correto, pis_incorreto)
})

context("Teste do CNPJ")

test_that("CNPJ com caracters especiais", {
  saida <- valida_doc("60.149.443/0001-70", type = "cnpj")
  expect_equal(saida, TRUE)
})

test_that("CNPJ com caracters iguais", {
  saida <- valida_doc("11.111.111/1111-11", type = "cnpj")
  expect_equal(saida, FALSE)
})

test_that("CNPJ somente com carcters", {
  saida <- valida_doc("60149443000170", type = "cnpj")
  expect_equal(saida, TRUE)
})

test_that("CNPJ como numero", {
  saida <- valida_doc(60149443000170, type = "cnpj")
  expect_equal(saida, TRUE)
})

test_that("CNPJ errado", {
  saida <- valida_doc(60149443000171, type = "cnpj")
  expect_equal(saida, FALSE)
})

test_that("CNPJ com tamanho errado", {
  saida <- valida_doc(6014944300017, type = "cnpj")
  expect_equal(saida, FALSE)
})

test_that("Conjunto de CNPJS", {
  cnpjs <- c(16784319000195, 11318414000180, 79417547000147)
  names <- c("BB", "Caixa", "Ipea")
  df <- data.frame(names = names, cnpjs = cnpjs)
  result <- valida_doc(df$cnpjs, type = "cnpj")
  expect_equal(result, c(TRUE, TRUE, TRUE))
})

test_that("Generate cnpj", {
  cnpj_incorreto <- c("522641040001", "297438670001", "855840660001")
  cnpj_correto <- c("52264104000107", "29743867000119", "85584066000129")
  gera_digito(cnpj_incorreto, type = "cnpj")
  expect_equal(cnpj_correto, cnpj_incorreto)
})

# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

converter_ra_ <- function(x) {
    .Call(`_documentosbr_converter_ra_`, x)
}

valida_ra <- function(x, type, log) {
    .Call(`_documentosbr_valida_ra`, x, type, log)
}

generate_digit <- function(x, type) {
    invisible(.Call(`_documentosbr_generate_digit`, x, type))
}

#' Check Brazilian documents.
#'
#' \code{valida_doc} returns true or false if the number of document is correct.
#'
#'
#' @param entrada Character or numeric of the document that will be validated.
#' @param type Character, it could be CPF, CNPJ, PIS e titulo de eleitor.
#' @param log Output errs found on entrada
#'
#' @importFrom Rcpp sourceCpp
#' @import data.table
#' @return True or False. if log is giving return a data frame.
#'
#' @examples
#'  valida_doc("529.982.247-25", type = "cpf")
#'  valida_doc("529.982.247-25", type = "pis")
#'  valida_doc("529.982.247-25", type = "cnes")
#'  valida_doc("60.149.443/0001-70", type = "cnpj")
#' @export
#'
valida_doc <- function(entrada, type = "cpf", log = FALSE){
  erros <- NULL
  if(type == "tituloeleitor"){
    if(log == FALSE){
      result <- verificar_titulo_eleitor(entrada)
    }else{
      result <- verificar_titulo_eleitor(entrada, log = TRUE)
    }
  }else{
    result <- valida_ra(entrada, type, log)
    if(log == TRUE){
      data.table::setDT(result)
      t <- data.table("Corretos"=0,"Primeiro digito errado"=1,"Segundo Digito errado"=2,"Todos os digitos iguais"=3)
      result[, erros:=names(t)[match(erros, t)]]
    }
  }
  result
}

#' Check Brazilian documents.
#'
#' \code{valida_doc_df} returns true or false if the number of document is correct.
#'
#'
#' @param data Data frame with data to be validate.
#' @param column Column of data that will be evaluated.
#' @param type Character, it could be CPF, CNPJ, PIS e titulo de eleitor.
#' @param log Output errs found on entrada
#'
#' @return True or False. if log is giving return a data frame.
#'
#' @export
#'
valida_doc_df <- function(data, column, type = "cpf", log = FALSE){
  arguments <- as.list(match.call())
  column = eval(arguments$column, data)
  valida_doc(column, type = type, log = log)
}

context("Teste do CNS")

test_that("CNS start with 7", {
  saida <- valida_doc("772367104660002", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS start with 8", {
  saida <- valida_doc("874822955230003", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS start with 9", {
  saida <- valida_doc("974181962520005", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS start with 1", {
  saida <- valida_doc("187086233720003", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS start with 2", {
  saida <- valida_doc("207545695560018", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS is giving with just caracters", {
  saida <- valida_doc("934803264080006", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("CNS is giving as a numeric", {
  saida <- valida_doc("294075364490018", type = "CNS")
  expect_equal(saida, TRUE)
})

test_that("A wrong CNS is giving", {
  saida <- valida_doc("294075364490008", type = "CNS")
  expect_equal(saida, FALSE)
})

test_that("CNS is givin a data frame column", {
  CNS <- c("934803264080006", "294075364490018", "194457319220009", "772367104660002", "874822955230003")
  names <- c("João", "Maria", "Josefina","Belcholina","Pedrita")
  df <- data.frame(names = names, CNS = CNS, stringsAsFactors = F)
  result <- valida_doc(df$CNS, type = "CNS")
  expect_equal(result, c(TRUE, TRUE, TRUE, TRUE, TRUE))
})

context("Teste do CPF")

test_that("Cpf com caracteres especiais", {
  saida <- valida_doc("529.982.247-25")
  expect_equal(saida, TRUE)
})

test_that("Cpf com caracteres todos iguais", {
  saida <- valida_doc("000.000.000-00")
  expect_equal(saida, FALSE)
})

test_that("Cpf somente com caracteres", {
  saida <- valida_doc("52998224725")
  expect_equal(saida, TRUE)
})

test_that("Cpf como numero", {
  saida <- valida_doc(52998224725)
  expect_equal(saida, TRUE)
})

test_that("Cpf errado", {
  saida <- valida_doc(52998224720)
  expect_equal(saida, FALSE)
})

test_that("Cpf numerico com zero no inicio", {
  saida <- valida_doc(00566619245)
  expect_equal(saida, TRUE)
})

# test_that("Cpf como factor", {
#   saida <- valida_doc(as.factor("086.090.706-62"))
#   #cat("\nA saida do cpf como factor: ", saida, " ", isTRUE(saida), "\n")
#   expect_equal(saida, TRUE)
# })

test_that("CPF issue #16 causava crash", {
  saida <- valida_doc("366501887", type = "cpf", log = FALSE)
  expect_equal(saida,TRUE)
})

test_that("Vetor de cpfs", {
  cpfs <- c(31338763849, 70628182597, 45178861400)
  names <- c("Pedro", "Joao", "Augusto")
  df <- data.frame(names = names, cpf = cpfs)
  result <- valida_doc(df$cpf)
  expect_equal(result, c(TRUE, TRUE, TRUE))
})

test_that("Data frame de cpfs", {
  load("data_frame_cpfs_teste.rda")
  result <- valida_doc_df(dados,id, type = "cpf")
  expect_equal(result, c(TRUE, TRUE, TRUE, TRUE))
})

test_that("Data frame de cpfs e log true", {
  load("data_frame_cpfs_teste.rda")
  load("resultado_cpf_log.rda")
  result <- valida_doc_df(dados,id, type = "cpf", log = TRUE)
  expect_equal(result, resultado)
})

test_that("Generate cpf", {
  cpf_incorreto <- c("263.364.246", "943.888.158", "533.103.723")
  cpf_correto <- c("26336424626", "94388815810", "53310372324")
  gera_digito(cpf_incorreto, type = "cpf")
  expect_equal(cpf_correto, cpf_incorreto)
})

context("Teste do Titulo de Eleitor")

test_that("Titulo de Eleitor com caracters especiais", {
  saida <- valida_doc("43568709/06", type = "tituloeleitor")
  expect_equal(saida, TRUE)
})

test_that("Titulo de Eleitor somente com carcters", {
  saida <- valida_doc("43568709/06", type = "tituloeleitor")
  expect_equal(saida, TRUE)
})

test_that("Titulo de Eleitor como numero", {
  saida <- valida_doc( 4356870906, type = "tituloeleitor")
  expect_equal(saida, TRUE)
})

test_that("Titulo de Eleitor errado", {
  saida <- valida_doc( 4356870907, type = "tituloeleitor")
  expect_equal(saida, FALSE)
})

---
title: "Introduction to documentosbr / Introdução ao documentosbr"
author: "Rodrigo Borges"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Introduction to documentosbr / Introdução ao documentosbr}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---


```{r, include=FALSE}
oldwidth <- options("width")
options(width = "800")
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 7,
  fig.height = 5
)
```


<style>
  .column {float: left;width: 50%;padding: 10px;}
  .row:after {content: "";display: table;clear: both;}
  @media screen and (max-width: 600px) {
    .column { width: 100%; }}
  body { text-align: justify; }
  .logo-container {text-align: center;margin-bottom: 20px;}
  </style>
  
  <div class="logo-container"><img src="../man/figures/documentosbr.svg" alt="documentosbr logo" width="200" style="border:none;"/></div>
  
  <div class="row"><div class="column">
  
# English
  
The documentosbr package provides a high-performance suite for validating and handling Brazilian administrative records. It currently supports:
  - **CPF** (Individual Taxpayer Registry)
  - **CNPJ** (National Registry of Legal Entities)
  - **PIS** (Social Integration Program)
  - **CNS/CNES** (National Health Card)
  
The core is implemented in C++ using Rcpp, allowing for extremely fast validation even on datasets with millions of observations.
  
## Validation Logic
  
Most Brazilian identifiers use "Module 11" checksums. While CPF and CNPJ share similar weighted-sum structures, the **CNS** (National Health Card) uses a dynamic algorithm that changes based on the starting digit (1-2 or 7-9).</div>
  <div class="column">
# Português

O pacote documentosbr oferece uma suíte de alta performance para a validação e manipulação de registros administrativos brasileiros. Atualmente, o pacote suporta:
 - **CPF** (Cadastro de Pessoa Física)
 - **CNPJ** (Cadastro Nacional de Pessoa Jurídica)
 - **PIS** (Programa de Integração Social)
 - **CNS/CNES** (Cartão Nacional de Saúde)

O núcleo é implementado em C++ via Rcpp, permitindo validações extremamente rápidas mesmo em bases de dados com milhões de observações.

## Lógica de Validação

A maioria dos identificadores brasileiros utiliza o sistema de "Módulo 11". Enquanto CPF e CNPJ compartilham estruturas de somas ponderadas similares, o **CNS** utiliza um algoritmo dinâmico que varia conforme o dígito inicial (1-2 ou 7-9).</div></div>

<hr>Installation / Instalação


```{r eval = FALSE}
# From CRAN / Via CRAN
install.packages("documentosbr")

# Development version / Versão de desenvolvimento
# remotes::install_github("rodrigo-borges/documentosbr")
```


<hr>
## Basic Usage / Uso Básico
<div class="row"><div class="column">

The valida_doc() function is the primary interface. It is vectorized and highly efficient. Use the type argument to specify the document and log = TRUE for detailed error reporting.</div>

<div class="column">
A função valida_doc() é a interface principal. Ela é vetorizada e altamente eficiente. Use o argumento type para especificar o documento e log = TRUE para relatórios detalhados de erro.</div></div>


```{r eval = FALSE}
library(documentosbr)

# Vectorized validation / Validação vetorizada
cpfs <- c("12345678901", "56273869596")
valida_doc(cpfs, type = "cpf")

# Health Card (CNS) / Cartão Nacional de Saúde
valida_doc("123456789012345", type = "cnes")
```


<hr>
## Performance / Performance
<div class="row"><div class="column">By offloading validation to C++, documentosbr minimizes overhead in ETL pipelines, making it suitable for large-scale data cleaning tasks in administrative records.</div><div class="column">Ao delegar a validação para o C++, o documentosbr minimiza o gargalo em fluxos de ETL, sendo ideal para tarefas de limpeza de dados em larga escala em registros administrativos.</div></div>


Caso deseje uma saída mais verbosa a função pode ser chamada da seguinte forma:

```{r}
library(documentosbr)
d <- valida_doc("56273869595", type = "pis", log = T)

```

```{r, echo=FALSE}
knitr::kable(d)
options(oldwidth)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/valida_documento.R
\name{valida_doc}
\alias{valida_doc}
\title{Check Brazilian documents.}
\usage{
valida_doc(entrada, type = "cpf", log = FALSE)
}
\arguments{
\item{entrada}{Character or numeric of the document that will be validated.}

\item{type}{Character, it could be CPF, CNPJ, PIS e titulo de eleitor.}

\item{log}{Output errs found on entrada}
}
\value{
True or False. if log is giving return a data frame.
}
\description{
\code{valida_doc} returns true or false if the number of document is correct.
}
\examples{
 valida_doc("529.982.247-25", type = "cpf")
 valida_doc("529.982.247-25", type = "pis")
 valida_doc("529.982.247-25", type = "cnes")
 valida_doc("60.149.443/0001-70", type = "cnpj")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/valida_titulo_eleitor.R
\name{verificar_titulo_eleitor}
\alias{verificar_titulo_eleitor}
\title{Validar Título de Eleitor}
\usage{
verificar_titulo_eleitor(entrada, log = FALSE)
}
\arguments{
\item{entrada}{Um \code{character}, \code{numeric} ou \code{integer} representando 
o número do título. Caracteres não numéricos são removidos automaticamente.}

\item{log}{\code{logical}. Se \code{TRUE}, permite o rastreio do processo (atualmente não implementado no corpo da função).}
}
\value{
Retorna um valor lógico: \code{TRUE} se o título for válido, 
\code{FALSE} caso contrário.
}
\description{
Verifica se um número de Título de Eleitor é válido utilizando o algoritmo 
de dígito verificador baseado em pesos e restos de divisão (módulo 11).
}
\examples{
# Exemplo com título válido (formato string)
verificar_titulo_eleitor("293116340175")

# Exemplo com título válido (formato numérico)
verificar_titulo_eleitor(293116340175)

# Exemplo com título inválido
verificar_titulo_eleitor("123456789012")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/converter_ra.R
\name{doc2integer64}
\alias{doc2integer64}
\title{Convert Brazilian documents.}
\usage{
doc2integer64(entrada)
}
\arguments{
\item{entrada}{Character or numeric that will be converted.}
}
\value{
an bit64 integer
}
\description{
\code{doc2integer64} returns a Brazilian document without special characters and as an integer64.
}
\examples{
   doc2integer64("086.090.705-65")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tratadocumento.R
\name{trata_cpf}
\alias{trata_cpf}
\title{Correct Brazilian cpf document.}
\usage{
trata_cpf(entrada)
}
\arguments{
\item{entrada}{Character or numeric of the document that will be adjusted.}
}
\value{
Entrada adjusted.
}
\description{
\code{trada_cpf} The aim is transform the entrada to the pattern of Brazilian document cpf.
                 It must have 11 numeric characters. When a dataset is read as a numeric,
                 it lost the 0 character on the left. This function fix that lost and transform
                 entrada to character.
}
\examples{
   trata_cpf(52145795)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gera_digitos.R
\name{gera_digito}
\alias{gera_digito}
\title{Complete Brazilian documents.}
\usage{
gera_digito(entrada, type = "cpf")
}
\arguments{
\item{entrada}{Character or numeric of the document that will be validated.}

\item{type}{Character, it could be CPF, CNPF, PIS e titulo de eleitor.}
}
\value{
it will alter the number by reference.
}
\description{
\code{gera_digito} generate the last digit of a administrative register.
}
\examples{
 gera_digito("529.982.247-2", type = "cpf")
 gera_digito("60.149.443/0001-7", type = "cnpj")
}
